==> deltasimulator-0.5.1.tar.gz: deltasimulator-0.5.1/test/data/test_forked.h <==
#ifndef __NODE_0_MODULE__
#define __NODE_0_MODULE__

#include <string>
#include <systemc>
using namespace sc_core;

class Node_0_module : public sc_module
{
private:
    uint64_t no_ins, no_outs;
    void set_sysc_return();
public:
    uint64_t no_inputs, no_outputs;
    sc_fifo<sc_dt::sc_bv<32>>* sysc_return;
    int get_no_inputs() const;
    int get_no_outputs() const;
    void body();
    SC_HAS_PROCESS(Node_0_module);
    Node_0_module(sc_module_name name);
};
#endif
#ifndef __ADD_2_ADD_3_1_MODULE__
#define __ADD_2_ADD_3_1_MODULE__

#include <string>
#include <systemc>
using namespace sc_core;
#include "Python.h"

class Add_2_Add_3_1_module : public sc_module
{
private:
    PyObject *pBody, *pName, *pModule, *pyC, *pExit;
    uint64_t no_ins, no_outs;
    PyObject* type_sysc_n;
    PyObject* get_sysc_n();
    sc_dt::sc_bv<32> bits_sysc_n;
    PyObject* type_sysc_a;
    sc_dt::sc_bv<32> bits_sysc_a;
    void set_sysc_a();
    PyObject* type_sysc_b;
    sc_dt::sc_bv<32> bits_sysc_b;
    void set_sysc_b();
public:
    uint64_t no_inputs, no_outputs;
    sc_fifo<sc_dt::sc_bv<32>>* sysc_n;
    sc_fifo<sc_dt::sc_bv<32>>* sysc_a;
    sc_fifo<sc_dt::sc_bv<32>>* sysc_b;
    int get_no_inputs() const;
    int get_no_outputs() const;
    void body();
    SC_HAS_PROCESS(Add_2_Add_3_1_module);
    Add_2_Add_3_1_module(sc_module_name name);
};
#endif
#ifndef __ADD_2_MODULE__
#define __ADD_2_MODULE__

#include <string>
#include <systemc>
using namespace sc_core;
#include "Python.h"

class Add_2_module : public sc_module
{
private:
    PyObject *pBody, *pName, *pModule, *pyC, *pExit;
    uint64_t no_ins, no_outs;
    PyObject* type_sysc_a;
    PyObject* get_sysc_a();
    sc_dt::sc_bv<32> bits_sysc_a;
    PyObject* type_sysc_b;
    PyObject* get_sysc_b();
    sc_dt::sc_bv<32> bits_sysc_b;
    PyObject* type_sysc_return;
    sc_dt::sc_bv<32> bits_sysc_return;
    void set_sysc_return();
public:
    uint64_t no_inputs, no_outputs;
    sc_fifo<sc_dt::sc_bv<32>>* sysc_a;
    sc_fifo<sc_dt::sc_bv<32>>* sysc_b;
    sc_fifo<sc_dt::sc_bv<32>>* sysc_return;
    int get_no_inputs() const;
    int get_no_outputs() const;
    void body();
    SC_HAS_PROCESS(Add_2_module);
    Add_2_module(sc_module_name name);
};
#endif
#ifndef __PRINT_THEN_EXIT_3_MODULE__
#define __PRINT_THEN_EXIT_3_MODULE__

#include <string>
#include <systemc>
using namespace sc_core;
#include "Python.h"

class Print_Then_Exit_3_module : public sc_module
{
private:
    PyObject *pBody, *pName, *pModule, *pyC, *pExit;
    uint64_t no_ins, no_outs;
    PyObject* type_sysc_n;
    PyObject* get_sysc_n();
    sc_dt::sc_bv<32> bits_sysc_n;
public:
    uint64_t no_inputs, no_outputs;
    sc_fifo<sc_dt::sc_bv<32>>* sysc_n;
    int get_no_inputs() const;
    int get_no_outputs() const;
    void body();
    SC_HAS_PROCESS(Print_Then_Exit_3_module);
    Print_Then_Exit_3_module(sc_module_name name);
};
#endif

#ifndef __TEST_FORKED__
#define __TEST_FORKED__
#include <systemc>
using namespace sc_core;
using namespace sc_dt;

// TODO: Find better way of handling trace files
sc_trace_file *Tf;

// Converts clock signals to bit vectors for Migen nodes
SC_MODULE(ClkToBV) {
    sc_in<bool> clk;
    sc_out<sc_bv<1>> clkout;

    void run() {
        clkout.write(clk.read());
    }

    SC_CTOR(ClkToBV) {
        SC_METHOD(run);
        sensitive << clk;
    }
};

// Adaptor for going from Python to Migen
template <class T> SC_MODULE(PythonToMigen) {
    sc_in<bool> clk;
    sc_out<T> migen_data_out;
    sc_out<sc_bv<1>> migen_valid_out;
    sc_in<sc_bv<1>> migen_ready_in;
    sc_fifo<T>* py_in;

    void run() {
        if (migen_ready_in.read() == 1) {
            T val;
            if (py_in->nb_read(val)) {
                migen_data_out.write(val);
                migen_valid_out.write(1);
            } else {
                migen_valid_out.write(0);
            }
        }
    }

    SC_CTOR(PythonToMigen) {
        SC_METHOD(run);
        sensitive << clk.pos();
    }
};

// Adaptor for going from Migen to Python
template <class T> SC_MODULE(MigenToPython) {
    sc_in<bool> clk;
    sc_in<T> migen_in;
    sc_in<sc_bv<1>> migen_valid_in;
    sc_out<sc_bv<1>> migen_ready_out;
    sc_fifo<T>* py_out;

    void run() {
        while (true) {
            wait();
            if (py_out->num_free() > 0) {
                migen_ready_out.write(1);
                if (migen_valid_in.read() == 1) {
                    py_out->write(migen_in.read());
                }
            } else {
                migen_ready_out.write(0);
            }
        }
    }

    SC_CTOR(MigenToPython) {
        SC_THREAD(run);
        sensitive << clk.pos();
    }
};

SC_MODULE(Test_Forked){

// Python nodes to Python nodes just need a queue
sc_fifo<sc_dt::sc_bv<32>> wire_0_0_1_0;
sc_fifo<sc_dt::sc_bv<32>> wire_1_0_2_0;
sc_fifo<sc_dt::sc_bv<32>> wire_1_1_2_1;
sc_fifo<sc_dt::sc_bv<32>> wire_2_0_3_0;

// Migen nodes to Migen nodes need data wires,
// as well as valid and ready signals

// Python to Migen need an adaptor which maps a queue
// to data, valid and ready signals.

// Migen to Python need an adaptor which maps signals
// to a queue

// Python to template need a public queue

// Template to python need a public queue

// Migen to template need public data, valid and ready signals

// Template to Migen need public data, valid and ready signals

sc_in<bool> clk, rst;
sc_signal<sc_dt::sc_bv<1>> rst_bv;

// Node modules
Node_0_module node_0;
Add_2_Add_3_1_module add_2_add_3_1;
Add_2_module add_2;
Print_Then_Exit_3_module print_then_exit_3;


// Constructor first initialises queues, modules and adaptors
typedef Test_Forked SC_CURRENT_USER_MODULE;
Test_Forked(sc_module_name name, sc_trace_file *Tf):
wire_0_0_1_0("wire_0_0_1_0"),
wire_1_0_2_0("wire_1_0_2_0"),
wire_1_1_2_1("wire_1_1_2_1"),
wire_2_0_3_0("wire_2_0_3_0"),
node_0("node_0"),
add_2_add_3_1("add_2_add_3_1"),
add_2("add_2"),
print_then_exit_3("print_then_exit_3")
{
    SC_METHOD(rstprop);
    sensitive << rst;

    // Wiring the clock to the Migen nodes

    // Wiring the Python to Python nodes
    node_0.sysc_return = &wire_0_0_1_0;
    add_2_add_3_1.sysc_n = &wire_0_0_1_0;
    add_2_add_3_1.sysc_a = &wire_1_0_2_0;
    add_2.sysc_a = &wire_1_0_2_0;
    add_2_add_3_1.sysc_b = &wire_1_1_2_1;
    add_2.sysc_b = &wire_1_1_2_1;
    add_2.sysc_return = &wire_2_0_3_0;
    print_then_exit_3.sysc_n = &wire_2_0_3_0;

    // Wiring the Migen to Migen nodes

    // Wiring the Python to Migen nodes

    // Wiring the Migen to Python nodes

    // Wiring the Python to template nodes

    // Wiring the template to Python nodes

    // Wiring the Migen to template nodes

    // Wiring the template to Migen nodes

    // Add tracing
    wire_0_0_1_0.trace(Tf);
    wire_1_0_2_0.trace(Tf);
    wire_1_1_2_1.trace(Tf);
    wire_2_0_3_0.trace(Tf);







}

void rstprop() {
    // Propogate reset signal to Migen nodes
    rst_bv.write(rst.read());
}

};

#endif

==> deltasimulator-0.6.1.tar.gz: deltasimulator-0.6.1/test/data/test_forked.h <==
#ifndef __NODE_0_MODULE__
#define __NODE_0_MODULE__

#include <string>
#include <systemc>
using namespace sc_core;

class Node_0_module : public sc_module
{
private:
    uint64_t no_ins, no_outs;
    void set_sysc_output();
public:
    uint64_t no_inputs, no_outputs;
    sc_fifo<sc_dt::sc_bv<32>>* sysc_output;
    int get_no_inputs() const;
    int get_no_outputs() const;
    void body();
    SC_HAS_PROCESS(Node_0_module);
    Node_0_module(sc_module_name name);
};
#endif
#ifndef __ADD_2_ADD_3_1_MODULE__
#define __ADD_2_ADD_3_1_MODULE__

#include <string>
#include <systemc>
using namespace sc_core;
#include "Python.h"

class Add_2_Add_3_1_module : public sc_module
{
private:
    PyObject *pBody, *pName, *pModule, *pyC, *pExit;
    uint64_t no_ins, no_outs;
    PyObject* type_sysc_n;
    PyObject* get_sysc_n();
    sc_dt::sc_bv<32> bits_sysc_n;
    PyObject* type_sysc_a;
    sc_dt::sc_bv<32> bits_sysc_a;
    void set_sysc_a();
    PyObject* type_sysc_b;
    sc_dt::sc_bv<32> bits_sysc_b;
    void set_sysc_b();
public:
    uint64_t no_inputs, no_outputs;
    sc_fifo<sc_dt::sc_bv<32>>* sysc_n;
    sc_fifo<sc_dt::sc_bv<32>>* sysc_a;
    sc_fifo<sc_dt::sc_bv<32>>* sysc_b;
    int get_no_inputs() const;
    int get_no_outputs() const;
    void body();
    SC_HAS_PROCESS(Add_2_Add_3_1_module);
    Add_2_Add_3_1_module(sc_module_name name);
};
#endif
#ifndef __ADD_2_MODULE__
#define __ADD_2_MODULE__

#include <string>
#include <systemc>
using namespace sc_core;
#include "Python.h"

class Add_2_module : public sc_module
{
private:
    PyObject *pBody, *pName, *pModule, *pyC, *pExit;
    uint64_t no_ins, no_outs;
    PyObject* type_sysc_a;
    PyObject* get_sysc_a();
    sc_dt::sc_bv<32> bits_sysc_a;
    PyObject* type_sysc_b;
    PyObject* get_sysc_b();
    sc_dt::sc_bv<32> bits_sysc_b;
    PyObject* type_sysc_output;
    sc_dt::sc_bv<32> bits_sysc_output;
    void set_sysc_output();
public:
    uint64_t no_inputs, no_outputs;
    sc_fifo<sc_dt::sc_bv<32>>* sysc_a;
    sc_fifo<sc_dt::sc_bv<32>>* sysc_b;
    sc_fifo<sc_dt::sc_bv<32>>* sysc_output;
    int get_no_inputs() const;
    int get_no_outputs() const;
    void body();
    SC_HAS_PROCESS(Add_2_module);
    Add_2_module(sc_module_name name);
};
#endif
#ifndef __PRINT_THEN_EXIT_3_MODULE__
#define __PRINT_THEN_EXIT_3_MODULE__

#include <string>
#include <systemc>
using namespace sc_core;
#include "Python.h"

class Print_Then_Exit_3_module : public sc_module
{
private:
    PyObject *pBody, *pName, *pModule, *pyC, *pExit;
    uint64_t no_ins, no_outs;
    PyObject* type_sysc_n;
    PyObject* get_sysc_n();
    sc_dt::sc_bv<32> bits_sysc_n;
public:
    uint64_t no_inputs, no_outputs;
    sc_fifo<sc_dt::sc_bv<32>>* sysc_n;
    int get_no_inputs() const;
    int get_no_outputs() const;
    void body();
    SC_HAS_PROCESS(Print_Then_Exit_3_module);
    Print_Then_Exit_3_module(sc_module_name name);
};
#endif

#ifndef __TEST_FORKED__
#define __TEST_FORKED__
#include <systemc>
using namespace sc_core;
using namespace sc_dt;

// TODO: Find better way of handling trace files
sc_trace_file *Tf;

// Converts clock signals to bit vectors for Migen nodes
SC_MODULE(ClkToBV) {
    sc_in<bool> clk;
    sc_out<sc_bv<1>> clkout;

    void run() {
        clkout.write(clk.read());
    }

    SC_CTOR(ClkToBV) {
        SC_METHOD(run);
        sensitive << clk;
    }
};

// Adaptor for going from Python to Migen
template <class T> SC_MODULE(PythonToMigen) {
    sc_in<bool> clk;
    sc_out<T> migen_data_out;
    sc_out<sc_bv<1>> migen_valid_out;
    sc_in<sc_bv<1>> migen_ready_in;
    sc_fifo<T>* py_in;

    void run() {
        if (migen_ready_in.read() == 1) {
            T val;
            if (py_in->nb_read(val)) {
                migen_data_out.write(val);
                migen_valid_out.write(1);
            } else {
                migen_valid_out.write(0);
            }
        }
    }

    SC_CTOR(PythonToMigen) {
        SC_METHOD(run);
        sensitive << clk.pos();
    }
};

// Adaptor for going from Migen to Python
template <class T> SC_MODULE(MigenToPython) {
    sc_in<bool> clk;
    sc_in<T> migen_in;
    sc_in<sc_bv<1>> migen_valid_in;
    sc_out<sc_bv<1>> migen_ready_out;
    sc_fifo<T>* py_out;

    void run() {
        while (true) {
            wait();
            if (py_out->num_free() > 0) {
                migen_ready_out.write(1);
                if (migen_valid_in.read() == 1) {
                    py_out->write(migen_in.read());
                }
            } else {
                migen_ready_out.write(0);
            }
        }
    }

    SC_CTOR(MigenToPython) {
        SC_THREAD(run);
        sensitive << clk.pos();
    }
};

SC_MODULE(Test_Forked){

// Python nodes to Python nodes just need a queue
sc_fifo<sc_dt::sc_bv<32>> wire_0_0_1_0;
sc_fifo<sc_dt::sc_bv<32>> wire_1_0_2_0;
sc_fifo<sc_dt::sc_bv<32>> wire_1_1_2_1;
sc_fifo<sc_dt::sc_bv<32>> wire_2_0_3_0;

// Migen nodes to Migen nodes need data wires,
// as well as valid and ready signals

// Python to Migen need an adaptor which maps a queue
// to data, valid and ready signals.

// Migen to Python need an adaptor which maps signals
// to a queue

// Python to template need a public queue

// Template to python need a public queue

// Migen to template need public data, valid and ready signals

// Template to Migen need public data, valid and ready signals

sc_in<bool> clk, rst;
sc_signal<sc_dt::sc_bv<1>> rst_bv;

// Node modules
Node_0_module node_0;
Add_2_Add_3_1_module add_2_add_3_1;
Add_2_module add_2;
Print_Then_Exit_3_module print_then_exit_3;


// Constructor first initialises queues, modules and adaptors
typedef Test_Forked SC_CURRENT_USER_MODULE;
Test_Forked(sc_module_name name, sc_trace_file *Tf):
wire_0_0_1_0("wire_0_0_1_0"),
wire_1_0_2_0("wire_1_0_2_0"),
wire_1_1_2_1("wire_1_1_2_1"),
wire_2_0_3_0("wire_2_0_3_0"),
node_0("node_0"),
add_2_add_3_1("add_2_add_3_1"),
add_2("add_2"),
print_then_exit_3("print_then_exit_3")
{
    SC_METHOD(rstprop);
    sensitive << rst;

    // Wiring the clock to the Migen nodes

    // Wiring the Python to Python nodes
    node_0.sysc_output = &wire_0_0_1_0;
    add_2_add_3_1.sysc_n = &wire_0_0_1_0;
    add_2_add_3_1.sysc_a = &wire_1_0_2_0;
    add_2.sysc_a = &wire_1_0_2_0;
    add_2_add_3_1.sysc_b = &wire_1_1_2_1;
    add_2.sysc_b = &wire_1_1_2_1;
    add_2.sysc_output = &wire_2_0_3_0;
    print_then_exit_3.sysc_n = &wire_2_0_3_0;

    // Wiring the Migen to Migen nodes

    // Wiring the Python to Migen nodes

    // Wiring the Migen to Python nodes

    // Wiring the Python to template nodes

    // Wiring the template to Python nodes

    // Wiring the Migen to template nodes

    // Wiring the template to Migen nodes

    // Add tracing
    wire_0_0_1_0.trace(Tf);
    wire_1_0_2_0.trace(Tf);
    wire_1_1_2_1.trace(Tf);
    wire_2_0_3_0.trace(Tf);







}

void rstprop() {
    // Propogate reset signal to Migen nodes
    rst_bv.write(rst.read());
}

};

#endif
